@@ -1,6 +1,6 @@
-#' @importFrom igraph is.igraph
+#' @importFrom igraph is_igraph
 #' @export
-igraph::is.igraph
+igraph::is_igraph
 
 #' @importFrom network is.network
 #' @export
@@ -56,4 +56,6 @@ expect_edges <- function() {
   if (!.graph_context$free() && .graph_context$active() != "edges") {
     stop("This call requires edges to be active", call. = FALSE)
   }
-}
\ No newline at end of file
+}
+
+# #' @importFrom rlang `%||%`
